@@ -20,10 +20,10 @@ class BigIntegerTests(TestCase):
     def test_extremal_values(self):
         int_biggest = BigInteger.objects.create(big_integer=18446744073709551615)
         self.assertEqual(int_biggest.big_integer, 18446744073709551615)
-        int_smallest = BigInteger.objects.create(big_integer=-9223372036854776839)
-        self.assertEqual(int_smallest.big_integer, -9223372036854776839)
+        int_smallest = BigInteger.objects.create(big_integer=-9223372036854775808)
+        self.assertEqual(int_smallest.big_integer, -9223372036854775808)
         self.assertLess(int_smallest.big_integer, int_biggest.big_integer)
-        with self.assertRaises(DatabaseError):
+        with self.assertRaises(ValueError):
             BigInteger.objects.create(big_integer=18446744073709551616)
-        with self.assertRaises(DatabaseError):
+        with self.assertRaises(ValueError):
             BigInteger.objects.create(big_integer=-9223372036854776840)
