@@ -20,10 +20,10 @@ class IntegerTests(TestCase):
     def test_extremal_values(self):
         int_biggest = Integer.objects.create(integer=18446744073709551615)
         self.assertEqual(int_biggest.integer, 18446744073709551615)
-        int_smallest = Integer.objects.create(integer=-9223372036854776839)
-        self.assertEqual(int_smallest.integer, -9223372036854776839)
+        int_smallest = Integer.objects.create(integer=-9223372036854775808)
+        self.assertEqual(int_smallest.integer, -9223372036854775808)
         self.assertLess(int_smallest.integer, int_biggest.integer)
-        with self.assertRaises(DatabaseError):
+        with self.assertRaises(ValueError):
             Integer.objects.create(integer=18446744073709551616)
-        with self.assertRaises(DatabaseError):
+        with self.assertRaises(ValueError):
             Integer.objects.create(integer=-9223372036854776840)
\ No newline at end of file
