@@ -20,10 +20,10 @@ class SmallIntegerTests(TestCase):
     def test_extremal_values(self):
         int_biggest = SmallInteger.objects.create(small_integer=18446744073709551615)
         self.assertEqual(int_biggest.small_integer, 18446744073709551615)
-        int_smallest = SmallInteger.objects.create(small_integer=-9223372036854776839)
-        self.assertEqual(int_smallest.small_integer, -9223372036854776839)
+        int_smallest = SmallInteger.objects.create(small_integer=-9223372036854775808)
+        self.assertEqual(int_smallest.small_integer, -9223372036854775808)
         self.assertLess(int_smallest.small_integer, int_biggest.small_integer)
-        with self.assertRaises(DatabaseError):
+        with self.assertRaises(ValueError):
             SmallInteger.objects.create(small_integer=18446744073709551616)
-        with self.assertRaises(DatabaseError):
+        with self.assertRaises(ValueError):
             SmallInteger.objects.create(small_integer=-9223372036854776840)
\ No newline at end of file
